Unreleased changes
------------------

Version 1
---------

1.6 / 2017-12-04
~~~~~~~~~~~~~~~~
* depend on latest jpp trunk (method renaming grrrrr) (find in THRONG)
* fix build script (was broken in 1.5.1, apparently)

1.5.1 / 2017-11-21
~~~~~~~~~~~~~~~~~~
* minor bugfixes. jfitreader now works (and has a km3pipe pump)
* DON'T USE

1.5.0 / 2017-11-21
~~~~~~~~~~~~~~~~~~
* Add preliminary jfit reader

1.4.0 / 2017-10-19
~~~~~~~~~~~~~~~~~~
* Adds timeslice and summary pump (preliminary)
